@@ -13,14 +13,13 @@ import shlex
 import subprocess  # nosec B404:blacklist import_subprocess
 from functools import wraps
 from getpass import getpass
-from pathlib import Path
 from typing import List, Dict, Any, Optional
 
 from .progress import CliProgress
 from .. import VERSION_WITH_DEPS
 from ..utils.config import Config, load_config, config_to_dict
 from .cli_builder import rename, return_to_stdout, partial, lazy_partial, \
-    Subcommands, Subcommand, SubcommandGroup, decorate, set_default
+    Subcommands, Subcommand, SubcommandGroup, decorate
 from ..utils.log import exception_to_message, add_stream_handler_to_logger, \
     add_rotating_file_handler_to_logger, create_logger
 from ..workflows.config import create as create_config
@@ -68,7 +67,7 @@ def get_passphrase_from_cmd(passphrase_cmd: str) -> str:
     except subprocess.CalledProcessError as e:
         raise UserError("Failed to read passphrase from "
                         f"'{passphrase_cmd}'. "
-                        f"{format(e.stderr.strip())}") from e
+                        f"{e.stderr.decode().strip()}") from e
 
 
 @exception_to_message(UserError, logger)
@@ -78,15 +77,25 @@ def get_passphrase_from_cmd_or_prompt(passphrase_cmd: Optional[str]) -> str:
     return getpass("Please enter your gpg private key password:")
 
 
+@exception_to_message(UserError, logger)
 @wraps(workflows_encrypt)
-def encrypt(*args, config: Config, dry_run: bool, passphrase_cmd: Optional[str],
+def encrypt(*args, config: Config, dry_run: bool,
+            passphrase_cmd: Optional[str],
+            dtr_id: Optional[int] = None,
+            offline: bool = False, verify_dtr: Optional[bool] = None,
             **kwargs):
+    if verify_dtr is None:
+        verify_dtr = not offline and dtr_id is not None
+    if offline and verify_dtr:
+        raise UserError(
+            "--verify_dtr is not possible when offline is enabled in the config")
     if config.sign_encrypted_data and not dry_run:
         kwargs["passphrase"] = get_passphrase_from_cmd_or_prompt(
             passphrase_cmd)
     else:
         kwargs["passphrase"] = None
-    return workflows_encrypt(*args, config=config, dry_run=dry_run, **kwargs)
+    return workflows_encrypt(*args, dtr_id=dtr_id, offline=offline, verify_dtr=verify_dtr,
+                             config=config, dry_run=dry_run, **kwargs)
 
 
 @wraps(workflows_decrypt)
@@ -108,7 +117,7 @@ def transfer(files: List[str],
              protocol=None,
              protocol_args: Dict[str, Any] = None,
              dry_run: bool = False,
-             verify: bool = True,
+             verify_dtr: Optional[bool] = None,
              progress=None):
     if connection is not None:
         if protocol is not None:
@@ -128,7 +137,7 @@ def transfer(files: List[str],
                               config=config,
                               two_factor_callback=two_factor_callback,
                               dry_run=dry_run,
-                              verify=verify,
+                              verify_dtr=verify_dtr,
                               progress=progress)
 
 
@@ -157,8 +166,8 @@ class Cli(Subcommands):
     subcommands = (
         Subcommand(
             decorate(encrypt,
-                     set_default(offline=config.offline),
-                     partial(config=config),
+                     partial(config=config,
+                             offline=config.offline),
                      lazy_partial(progress=CliProgress)
                      ),
             overrides={
@@ -170,9 +179,7 @@ class Cli(Subcommands):
                                   "with GPG key of data recipient(s).",
                                   alias='-r'),
                 "dtr_id": dict(help="Data Transfer Request (DTR) ID (optional)", alias='-t'),
-                "offline": dict(
-                    help="Offline mode: skip DTR ID validation and key "
-                         "refreshing."),
+                "verify_dtr": dict(help="Verify DTR ID", default=None),
                 "purpose": dict(
                     help="Purpose of the DTR (PRODUCTION, TEST)."
                          "Mandatory only if `transfer_id` is specified"),
@@ -212,7 +219,7 @@ class Cli(Subcommands):
                                    "config. The protocol args can be overwritten by "
                                    "the protocol_args option"),
                 "dry_run": dict(help="Use this flag to perform checks on the data only"),
-                "verify": dict(help="Verify DTR ID")
+                "verify_dtr": dict(help="Verify DTR ID")
             }),
         Subcommand(
             decorate(
