@@ -44,9 +44,6 @@ class CliProgress(ProgressInterface):
         if initial_print:
             self.print_current()
 
-    def set_label(self, label: str) -> None:
-        self.prefix = label
-
     def update(self, completed_fraction: float) -> None:
         t = time.time()
         completed_fraction_rounded = round(completed_fraction,
