@@ -21,10 +21,31 @@ def compute_checksum_sha256(file_object: IO[bytes],
     while block:
         hash_value.update(block)
         block = file_object.read(block_size)
-    file_object.seek(0)
     return hash_value.hexdigest()
 
 
+def compute_checksum_on_write(stream: IO[bytes],
+                              fout: io.FileIO,
+                              checksum_buffer: io.StringIO,
+                              block_size: int = 65536):
+    """Compute a sha256 checksum on stream while saving to a file.
+
+    :param stream: a stream of bytes to checksum and save.
+    :param fout: output file object.
+    :param checksum_buffer: a buffer to store the checksum.
+    :param block_size: size of blocks (in bytes) to be returned by the
+        generator function. The default block size is 2^16 = 65536 bytes.
+    """
+    hash_value = hashlib.sha256()
+    block = stream.read(block_size)
+    while block:
+        hash_value.update(block)
+        fout.write(block)
+        block = stream.read(block_size)
+    checksum_buffer.write(hash_value.hexdigest())
+    checksum_buffer.seek(0)
+
+
 def write_checksums(entries: Iterable[Tuple[str, IO[bytes]]]) -> bytes:
     """Returns bytes string containing lines in the format
     `<checksum> <file name>`
@@ -77,7 +98,7 @@ def verify_checksums(checksums: Iterable[Tuple[str, str]],
                                 f'\nGot: {computed}')
 
 
-def read_checksum_file(f: io.IOBase) -> Iterable[Tuple[str, str]]:
+def read_checksum_file(f: IO[bytes]) -> Iterable[Tuple[str, str]]:
     """Reads lines from a file object and parses them in the form:
      a7186ae7ff993b379qcf3567775cfc71a212rf217e4dd testDir/file1.fastq
      f8d2d394264823e711fgc34e4ac83f8cbc253c6we034f testDir/file2.fastq
