@@ -410,6 +410,6 @@ def request_key_signature(keyid: str, signing_endpoint: str) -> bool:
         with urlopen(signing_endpoint, data):  # nosec
             return True
     except urllib.error.HTTPError as e:
-        raise UserError(json.loads(e.read())["msg"]) from e
+        raise UserError(json.loads(e.read())[0]) from e
     except urllib.error.URLError:
         raise UserError("Could not connect to the server.") from None
