@@ -53,7 +53,7 @@ class DecryptTab(QtWidgets.QWidget, TabMixin):
                             btn_decrypt_only.isChecked()))
         group_extract.addButton(btn_decrypt_and_extract)
         group_extract.addButton(btn_decrypt_only)
-        output_location = PathInput()
+        output_location = PathInput(path=self.app_data.encrypt_output_location)
         output_location.status_tip = "Destination folder for the decrypted packages"
         output_location.on_path_change(
             partial(setattr, self.app_data, "decrypt_output_location"))
