@@ -81,7 +81,7 @@ class MainWindow(QtWidgets.QMainWindow):
     def closeEvent(self, event):
         if self.app_data.config.gui_quit_confirmation:
             reply = QtWidgets.QMessageBox.question(
-                self, "Quit", "Are you sure to quit?",
+                self, "Quit", "Do you really want to quit?",
                 QtWidgets.QMessageBox.Yes | QtWidgets.QMessageBox.No,
                 QtWidgets.QMessageBox.No)
             if reply == QtWidgets.QMessageBox.Yes:
