@@ -17,7 +17,7 @@ def parse_protocol(s: str):
     try:
         return protocols_by_name[s]
     except KeyError:
-        raise UserError(f"Invalid protocol: {s}")
+        raise UserError(f"Invalid protocol: {s}") from None
 
 
 def needs_argument(protocol, argument: str):
