@@ -40,10 +40,16 @@ def upload(files: List[str],  # nosec (False Positive: pkey_password_encoding)
                              pkey_password=pkey_password,
                              pkey_password_encoding=pkey_password_encoding,
                              two_factor_callback=two_factor_callback) as sftp:
-            sftp.mkdir(str(remote_dir))
+            try:
+                sftp.mkdir(str(remote_dir))
+            except FileNotFoundError as e:
+                raise UserError("Remote destination directory does not exist: "
+                                f"{destination_dir}") from e
+            except PermissionError as e:
+                raise UserError("You don not have enough permissions to write "
+                                f"to the remote directory: {destination_dir}"
+                                ) from e
             for tar in files:
-                if progress is not None:
-                    progress.set_label(tar)
                 remotepath = str(remote_dir / Path(tar).name)
                 remotepath_part = remotepath + ".part"
                 status = sftp.put(localpath=os.path.realpath(tar),
