@@ -54,6 +54,7 @@ class Config:
     connections: Dict[str, Connection] = dataclasses.field(
         default_factory=lambda: {})
     temp_dir: str = TMP_DIR
+    output_dir: Optional[str] = None
     ssh_password_encoding: str = "utf_8"
     default_sender: Optional[str] = None
     gui_quit_confirmation: bool = True
@@ -64,7 +65,7 @@ class Config:
 
     @property
     def dcc_portal_pgpkey_endpoint_url(self) -> str:
-        return self.dcc_portal_url + "/backend/pgpkey/"
+        return self.dcc_portal_url + "/backend/pgpkey-sign-request/"
 
     @property
     def dcc_portal_dpkg_endpoint_url(self) -> str:
@@ -79,8 +80,6 @@ class Config:
 def load_config() -> Config:
     """Loads the config, returning a Config object"""
 
-    migrate_repo_url()
-
     cfg_dct = sys_config_dict()
     cfg_dct.update(load_config_dict(get_config_file()))
     return deserialize(Config)(cfg_dct)
@@ -146,17 +145,3 @@ def get_config_dir() -> str:
         os.path.expanduser("~"),
         *conf_sub_dir_by_os[platform.system()],
         APP_NAME_SHORT)
-
-
-def migrate_repo_url():
-    """Migrate repo URL inside the config"""
-    cfg_file = get_config_file()
-    try:
-        with open(cfg_file) as f:
-            config_dict = json.load(f)
-        if config_dict.get("repo_url") == "https://pypi.dcc.sib.swiss":
-            config_dict["repo_url"] = Config().repo_url
-        with open(cfg_file, "w") as f:
-            json.dump(config_dict, f, indent=2, sort_keys=True)
-    except FileNotFoundError:
-        pass
