@@ -10,9 +10,6 @@ from functools import wraps
 class ProgressInterface:
     """Interface for progress objects."""
 
-    def set_label(self, label: str) -> None:
-        """"Method to associate a label to a progress object."""
-
     def update(self, completed_fraction: float) -> None:
         """Method to update the status of a progress object to a new
         fraction of completeness.
@@ -120,10 +117,12 @@ def weights_to_ranges(weights: Sequence[float],
     ranges, where the first has twice the size of the second and third:
     (0.0, 0.5), (0.5, 0.75), (0.75, 1.0).
     """
-    sum_of_weights = sum(weights)
-    stop = weights[0] / sum_of_weights
+    # Ensure that empty files are > 0 for progress computation
+    safe_weights = [w or 1.0 for w in weights]
+    sum_of_weights = sum(safe_weights)
+    stop = safe_weights[0] / sum_of_weights
     yield (start, stop)
-    for weight in weights[1:]:
+    for weight in safe_weights[1:]:
         start = stop
         stop += weight / sum_of_weights
         yield (start, stop)
@@ -188,8 +187,6 @@ def scale_progress(progress: ProgressInterface,
     # method is modified so it automatically rescales its inputs to the
     # desired range of values.
     class SubProgress(ProgressInterface):
-        def set_label(self, label: str):
-            return progress.set_label(label)
 
         def update(self, completed_fraction: float) -> None:
             """Rescale the completed_fraction value so that its value is
@@ -211,8 +208,7 @@ def scale_progress(progress: ProgressInterface,
 
 @contextmanager
 def subprogress(progress: Optional[ProgressInterface],
-                step_completion_increase: float,
-                step_label: str = ''):
+                step_completion_increase: float):
     """Context manager for running a progress bar or a subset of a progress
     bar (i.e. a "scaled progress".
     Usage example:
@@ -227,7 +223,6 @@ def subprogress(progress: Optional[ProgressInterface],
         fraction value of the progress interface. So if at the start of the
         subprogress step the completed fraction is 0.25, then at the end the
         value will be 0.55 (0.25 + 0.3).
-    :param step_label: label associated with the current step.
     :return: A ProgressInterface instance covering the range starting at the
         current position of :progress: and advancing :step_completion_increase:
     :raises ValueError:
@@ -235,7 +230,6 @@ def subprogress(progress: Optional[ProgressInterface],
     if progress is None:
         yield None
         return
-    progress.set_label(step_label)
     start = progress.get_completed_fraction()
     stop = start + step_completion_increase
     if stop > 1.0:
@@ -262,6 +256,7 @@ class FileObjectProgress:
 
         if total_size == 0:
             def wrap_update(f):
+                progress.update(1)
                 return f
         else:
             def wrap_update(f):
@@ -366,9 +361,6 @@ def progress_file_iter(files: List[str],
     :return: file objects with backed-in subprogress.
     """
     file_size = [float(os.path.getsize(f)) for f in files]
-    if sum(file_size) == 0:
-        yield from (cast(IO[bytes], Opener(f, mode)) for f in files)
-        return
     files_with_progress = progress_iter_with_sub_progress(
         iterable=files,
         progress=progress,
